@@ -7,4 +7,7 @@ from .receipt import Receipt, Log
 from .trace import Trace, TraceAction, TraceResult
 from .event_type import EventType
 from .network import Network
-from .utils import get_forta_config, get_json_rpc_url, create_block_event, create_transaction_event
+from .utils import get_json_rpc_url, create_block_event, create_transaction_event, get_web3_provider
+from web3 import Web3
+
+web3Provider = Web3(Web3.HTTPProvider(get_json_rpc_url()))
